#pragma clang diagnostic ignored "-Wmissing-prototypes"

#include <metal_stdlib>
#include <simd/simd.h>

using namespace metal;

template<typename T>
T spvFMul(T l, T r)
{
	return fma(l, r, T(0));
}

template<typename T, int Cols, int Rows>
vec<T, Cols> spvFMulVectorMatrix(vec<T, Rows> v, matrix<T, Cols, Rows> m)
{
	vec<T, Cols> res = vec<T, Cols>(0);
	for (uint i = Rows; i > 0; --i)
	{
		vec<T, Cols> tmp(0);
		for (uint j = 0; j < Cols; ++j)
		{
			tmp[j] = m[j][i - 1];
		}
		res = fma(tmp, vec<T, Cols>(v[i - 1]), res);
	}
	return res;
}

template<typename T, int Cols, int Rows>
vec<T, Rows> spvFMulMatrixVector(matrix<T, Cols, Rows> m, vec<T, Cols> v)
{
	vec<T, Rows> res = vec<T, Rows>(0);
	for (uint i = Cols; i > 0; --i)
	{
		res = fma(m[i - 1], vec<T, Rows>(v[i - 1]), res);
	}
	return res;
}

template<typename T, int LCols, int LRows, int RCols, int RRows>
matrix<T, RCols, LRows> spvFMulMatrixMatrix(matrix<T, LCols, LRows> l, matrix<T, RCols, RRows> r)
{
	matrix<T, RCols, LRows> res;
	for (uint i = 0; i < RCols; i++)
	{
		vec<T, RCols> tmp(0);
		for (uint j = 0; j < LCols; j++)
		{
			tmp = fma(vec<T, RCols>(r[i][j]), l[j], tmp);
		}
		res[i] = tmp;
	}
	return res;
}

template<typename T>
T spvFAdd(T l, T r)
{
	return fma(T(1), l, r);
}

template<typename T>
[[clang::optnone]] T spvONFAdd(T l, T r)
{
	return fma(T(1), l, r);
}

struct cb58_struct
{
	float4 _m0[58];
};

struct cb33_struct
{
	float4 _m0[33];
};

struct cb1_struct
{
	float4 _m0[1];
};

struct vs0_out
{
	float4 o1 [[user(locn1)]];
	float2 o2 [[user(locn2)]];
	float3 o3 [[user(locn3)]];
	float4 gl_Position [[position]];
};

struct vs0_in
{
	float4 v1 [[attribute(1)]];
	float3 v2 [[attribute(2)]];
	float4 v4 [[attribute(4)]];
	float2 v5 [[attribute(5)]];
};

vertex vs0_out vs0(vs0_in in [[stage_in]], constant cb1_struct& cb0_0 [[buffer(0)]], constant cb58_struct& cb10_10 [[buffer(1)]], constant cb33_struct& cb3_3 [[buffer(4)]], texture_buffer<uint> t4 [[texture(60)]], uint gl_InstanceIndex [[instance_id]], uint gl_BaseInstance [[base_instance]])
{
	vs0_out out = {};
	float4 v0;
	v0.x = as_type<float>(int(gl_InstanceIndex) - int(gl_BaseInstance));
	float4 r0;
	r0 = float4(float2(0.0, 1.0).x, r0.y, float2(0.0, 1.0).y, r0.w);
	r0.w = as_type<float>((as_type<int>(cb0_0._m0[0u].x) * 5184) + as_type<int>(v0.x));
	uint _100 = (uint(as_type<int>(r0.w)) * 8u) + (uint(0) >> 2u);
	float4 r1 = as_type<float4>(uint4(t4.read(uint(_100)).x, t4.read(uint((_100 + 2u))).x, t4.read(uint((_100 + 3u))).x, t4.read(uint((_100 + 1u))).x));
	r0.w = as_type<float>(t4.read(uint(((uint(as_type<int>(r0.w)) * 8u) + (uint(16) >> 2u)))).x);
	float4 r2;
	r2.x = dot(r1.xy, float2(0.3660254180431365966796875));
	float2 _137 = spvFAdd(r1.xy, r2.xx);
	r2 = float4(_137.x, _137.y, r2.z, r2.w);
	float2 _143 = floor(r2.xy);
	r2 = float4(_143.x, _143.y, r2.z, r2.w);
	float2 _150 = spvFMul(r2.xy, float2(0.00346020772121846675872802734375));
	r2 = float4(r2.x, r2.y, _150.x, _150.y);
	float2 _155 = floor(r2.zw);
	r2 = float4(r2.x, r2.y, _155.x, _155.y);
	float2 _162 = spvFMul(r2.zw, float2(289.0));
	r2 = float4(r2.x, r2.y, _162.x, _162.y);
	float2 _170 = spvFAdd(-r2.zw, r2.xy);
	r2 = float4(r2.x, r2.y, _170.x, _170.y);
	float2 _178 = spvFAdd(r1.xy, -r2.xy);
	float4 r3;
	r3 = float4(_178.x, _178.y, r3.z, r3.w);
	r2.x = dot(r2.xy, float2(0.211324870586395263671875));
	float2 _191 = spvFAdd(r2.xx, r3.xy);
	r2 = float4(_191.x, _191.y, r2.z, r2.w);
	r3.x = as_type<float>((r2.y < r2.x) ? 4294967295u : 0u);
	r3 = select(float4(0.0, 1.0, -0.0, -1.0), float4(1.0, 0.0, -1.0, -0.0), as_type<uint4>(r3.xxxx) != uint4(0u));
	r0.y = r3.y;
	float3 _222 = spvFAdd(r0.xyz, r2.www);
	r0 = float4(_222.x, _222.y, _222.z, r0.w);
	float3 _229 = spvFMul(r0.xyz, float3(34.0));

	float4 r4;
	r4 = float4(_229.x, _229.y, _229.z, r4.w);
	float3 _235 = spvFAdd(r4.xyz, float3(1.0));
	r4 = float4(_235.x, _235.y, _235.z, r4.w);
	float3 _242 = spvFMul(r0.xyz, r4.xyz);
	r0 = float4(_242.x, _242.y, _242.z, r0.w);
	float3 _248 = spvFMul(r0.xyz, float3(0.00346020772121846675872802734375));
	r4 = float4(_248.x, _248.y, _248.z, r4.w);
	float3 _253 = floor(r4.xyz);
	r4 = float4(_253.x, _253.y, _253.z, r4.w);
	float3 _259 = spvFMul(r4.xyz, float3(289.0));
	r4 = float4(_259.x, _259.y, _259.z, r4.w);
	float3 _267 = spvFAdd(r0.xyz, -r4.xyz);
	r0 = float4(_267.x, _267.y, _267.z, r0.w);
	float3 _274 = spvFAdd(r2.zzz, r0.xyz);
	r0 = float4(_274.x, _274.y, _274.z, r0.w);
	r4 = float4(float2(0.0, 1.0).x, r4.y, float2(0.0, 1.0).y, r4.w);
	r4.y = r3.x;
	float3 _286 = spvFAdd(r0.xyz, r4.xyz);
	r0 = float4(_286.x, _286.y, _286.z, r0.w);
	float3 _291 = spvFMul(r0.xyz, float3(34.0));
	r4 = float4(_291.x, _291.y, _291.z, r4.w);
	float3 _296 = spvFAdd(r4.xyz, float3(1.0));
	r4 = float4(_296.x, _296.y, _296.z, r4.w);
	float3 _303 = spvFMul(r0.xyz, r4.xyz);
	r0 = float4(_303.x, _303.y, _303.z, r0.w);
	float3 _308 = spvFMul(r0.xyz, float3(0.00346020772121846675872802734375));
	r4 = float4(_308.x, _308.y, _308.z, r4.w);
	float3 _313 = floor(r4.xyz);
	r4 = float4(_313.x, _313.y, _313.z, r4.w);
	float3 _318 = spvFMul(r4.xyz, float3(289.0));
	r4 = float4(_318.x, _318.y, _318.z, r4.w);
	float3 _326 = spvFAdd(r0.xyz, -r4.xyz);
	r0 = float4(_326.x, _326.y, _326.z, r0.w);
	float3 _333 = spvFMul(r0.xyz, float3(0.024390242993831634521484375));
	r0 = float4(_333.x, _333.y, _333.z, r0.w);
	float3 _338 = fract(r0.xyz);
	r0 = float4(_338.x, _338.y, _338.z, r0.w);
	float3 _345 = spvFMul(r0.xyz, float3(2.0));
	r0 = float4(_345.x, _345.y, _345.z, r0.w);
	float3 _351 = spvFAdd(r0.xyz, float3(-1.0));
	r0 = float4(_351.x, _351.y, _351.z, r0.w);
	float3 _358 = spvFAdd(r0.xyz, float3(0.5));
	r4 = float4(_358.x, _358.y, _358.z, r4.w);
	float3 _363 = floor(r4.xyz);
	r4 = float4(_363.x, _363.y, _363.z, r4.w);
	float3 _371 = spvFAdd(r0.xyz, -r4.xyz);
	r4 = float4(_371.x, _371.y, _371.z, r4.w);
	float3 _379 = spvFAdd(abs(r0.xyz), float3(-0.5));
	r0 = float4(_379.x, _379.y, _379.z, r0.w);
	float3 _386 = spvFMul(r4.xyz, r4.xyz);
	float4 r5;
	r5 = float4(_386.x, _386.y, _386.z, r5.w);
	float3 _393 = spvFMul(r0.xyz, r0.xyz);
	float4 r6;
	r6 = float4(_393.x, _393.y, _393.z, r6.w);
	float3 _400 = spvFAdd(r5.xyz, r6.xyz);
	r5 = float4(_400.x, _400.y, _400.z, r5.w);
	float3 _407 = spvFMul(r5.xyz, float3(0.8537347316741943359375));
	r5 = float4(_407.x, _407.y, _407.z, r5.w);
	float3 _415 = spvFAdd(-r5.xyz, float3(1.792842864990234375));
	r5 = float4(_415.x, _415.y, _415.z, r5.w);
	r6 = spvFAdd(r2.xyxy, float4(0.211324870586395263671875, 0.211324870586395263671875, -0.57735025882720947265625, -0.57735025882720947265625));
	float2 _427 = spvFAdd(r3.zw, r6.xy);
	r6 = float4(_427.x, _427.y, r6.z, r6.w);
	r3.y = dot(r6.xy, r6.xy);
	r3.x = dot(r2.xy, r2.xy);
	r3.z = dot(r6.zw, r6.zw);
	float3 _451 = spvFAdd(-r3.xyz, float3(0.5));
	r3 = float4(_451.x, _451.y, _451.z, r3.w);
	float3 _457 = precise::max(r3.xyz, float3(0.0));
	r3 = float4(_457.x, _457.y, _457.z, r3.w);
	float3 _464 = spvFMul(r3.xyz, r3.xyz);
	r3 = float4(_464.x, _464.y, _464.z, r3.w);
	float3 _471 = spvFMul(r3.xyz, r3.xyz);
	r3 = float4(_471.x, _471.y, _471.z, r3.w);
	float3 _478 = spvFMul(r5.xyz, r3.xyz);
	r3 = float4(_478.x, _478.y, _478.z, r3.w);
	r2.x = spvFMul(r2.x, r4.x);
	float2 _491 = spvFMul(r4.yz, r6.xz);
	r2 = float4(r2.x, r2.y, _491.x, _491.y);
	float2 _498 = spvFMul(r0.yz, r6.yw);
	r0 = float4(r0.x, _498.x, _498.y, r0.w);
	r0.x = spvFMul(r2.y, r0.x);
	float3 _511 = spvFAdd(r0.xyz, r2.xzw);
	r4 = float4(_511.x, _511.y, _511.z, r4.w);
	r0.x = dot(r3.xyz, r4.xyz);
	r0.x = spvFMul(r0.x, 130.0);
	r0.x = spvFAdd(r0.x, in.v4.y);
	r0.x = spvFMul(r0.x, 6.283185482025146484375);
	r0.y = spvFMul(cb10_10._m0[57u].x, 0.25);
	r0.y = spvFMul(r0.y, cb10_10._m0[2u].w);
	r0.x = spvFAdd(r0.x, r0.y);
	r0.y = cos(r0.x);
	r2 = spvFMul(r0.xxxx, float4(3.0, 5.0, 7.0, 25.0));
	float3 _571 = cos(r2.xyz);
	r2 = float4(_571.x, _571.y, _571.z, r2.w);
	r0.x = sin(r2.w);
	r0.x = spvFMul(r0.x, 0.100000001490116119384765625);
	r0.y = spvFMul(r0.y, r2.x);
	r0.y = spvFMul(r2.y, r0.y);
	r0.y = spvFMul(r2.z, r0.y);
	r0.x = spvFAdd(r0.x, r0.y);
	float2 _614 = spvFMul(cb10_10._m0[55u].ww, float2(4.19999980926513671875, 0.3499999940395355224609375));
	r0 = float4(r0.x, _614.x, _614.y, r0.w);
	float2 _622 = spvFMul(r0.yz, cb10_10._m0[57u].yw);
	r0 = float4(r0.x, _622.x, _622.y, r0.w);
	r0.x = spvFMul(r0.y, r0.x);
	r0.y = dot(cb10_10._m0[55u].xyz, cb10_10._m0[55u].xyz);
	r0.y = rsqrt(r0.y);
	float3 _648 = spvFMul(r0.yyy, cb10_10._m0[55u].xyz);
	r2 = float4(_648.x, _648.y, _648.z, r2.w);
	float3 _655 = spvFMul(r0.xxx, r2.xyz);
	r3 = float4(_655.x, _655.y, _655.z, r3.w);
	r0.x = spvFAdd(-in.v4.z, 1.0);
	float3 _667 = spvFMul(r0.xxx, r3.xyz);
	r3 = float4(_667.x, _667.y, _667.z, r3.w);
	r4 = float4(float2(0.0, 1.0).x, r4.y, float2(0.0, 1.0).y, r4.w);
	r5 = float4(r5.x, float2(0.0, 1.0).x, r5.z, float2(0.0, 1.0).y);
	r6 = float4(r6.x, r6.y, r1.y, r1.x);
	r6.x = sin(r1.z);
	r0.x = cos(r1.z);
	r5.x = dot(float2(1.0, 0.0), r6.xz);
	r6.y = r0.x;
	r5.z = dot(float2(1.0, 0.0), r6.yz);
	float4 r7;
	r7.w = r6.z;
	float3 _702 = spvFMul(r0.www, r5.xyz);
	r7 = float4(_702.x, _702.y, _702.z, r7.w);
	r0.y = spvFMul(in.v1.w, 13.0);
	r0.y = exp2(r0.y);

	float3 _718 = spvFMul(r0.yyy, in.v1.xyz);
	r5 = float4(_718.x, _718.y, _718.z, r5.w);
	float4 r8;
	r8.y = dot(r7, r5);
	float4 r9;
	r9.y = 0.0;
	r6.x = -r6.x;
	r9.z = dot(float2(1.0, 0.0), r6.xw);
	r9.x = dot(float2(1.0, 0.0), r6.yw);
	float3 _742 = spvFMul(r0.www, r9.xyz);
	r6 = float4(_742.x, _742.y, _742.z, r6.w);
	r8.x = dot(r6, r5);
	r0.y = dot(r8.xy, float2(0.3660254180431365966796875));
	float2 _757 = spvFAdd(r0.yy, r8.xy);
	r8 = float4(r8.x, r8.y, _757.x, _757.y);
	float2 _762 = floor(r8.zw);
	r8 = float4(r8.x, r8.y, _762.x, _762.y);
	float2 _767 = spvFMul(r8.zw, float2(0.00346020772121846675872802734375));
	r9 = float4(_767.x, _767.y, r9.z, r9.w);
	float2 _772 = floor(r9.xy);
	r9 = float4(_772.x, _772.y, r9.z, r9.w);
	float2 _777 = spvFMul(r9.xy, float2(289.0));
	r9 = float4(_777.x, _777.y, r9.z, r9.w);
	float2 _785 = spvFAdd(r8.zw, -r9.xy);
	r9 = float4(_785.x, _785.y, r9.z, r9.w);
	float2 _793 = spvFAdd(-r8.zw, r8.xy);
	r9 = float4(r9.x, r9.y, _793.x, _793.y);
	r0.y = dot(r8.zw, float2(0.211324870586395263671875));
	r8.zw = spvFAdd(r0.yy, r9.zw);
	r8.xy = spvONFAdd(r1.xy, -r8.xy);
	r0.y = as_type<float>((r8.w < r8.z) ? 4294967295u : 0u);
	float4 r10 = select(float4(0.0, 1.0, -0.0, -1.0), float4(1.0, 0.0, -1.0, -0.0), as_type<uint4>(r0.yyyy) != uint4(0u));
	r4.y = r10.y;
	float3 _835 = spvONFAdd(r4.xyz, r9.yyy);
	r4 = float4(_835.x, _835.y, _835.z, r4.w);
	float3 _840 = spvFMul(r4.xyz, float3(34.0));
	r9 = float4(r9.x, _840.x, _840.y, _840.z);
	float3 _845 = spvFAdd(r9.yzw, float3(1.0));
	r9 = float4(r9.x, _845.x, _845.y, _845.z);
	float3 _852 = spvFMul(r4.xyz, r9.yzw);
	r4 = float4(_852.x, _852.y, _852.z, r4.w);
	float3 _857 = spvFMul(r4.xyz, float3(0.00346020772121846675872802734375));
	r9 = float4(r9.x, _857.x, _857.y, _857.z);
	float3 _862 = floor(r9.yzw);
	r9 = float4(r9.x, _862.x, _862.y, _862.z);
	float3 _867 = spvFMul(r9.yzw, float3(289.0));
	r9 = float4(r9.x, _867.x, _867.y, _867.z);
	float3 _875 = spvFAdd(r4.xyz, -r9.yzw);
	r4 = float4(_875.x, _875.y, _875.z, r4.w);
	float3 _882 = spvFAdd(r9.xxx, r4.xyz);
	r4 = float4(_882.x, _882.y, _882.z, r4.w);
	r9 = float4(float2(0.0, 1.0).x, r9.y, float2(0.0, 1.0).y, r9.w);
	r9.y = r10.x;
	float3 _894 = spvFAdd(r4.xyz, r9.xyz);
	r4 = float4(_894.x, _894.y, _894.z, r4.w);
	float3 _899 = spvFMul(r4.xyz, float3(34.0));
	r9 = float4(_899.x, _899.y, _899.z, r9.w);
	float3 _904 = spvFAdd(r9.xyz, float3(1.0));
	r9 = float4(_904.x, _904.y, _904.z, r9.w);
	float3 _911 = spvFMul(r4.xyz, r9.xyz);
	r4 = float4(_911.x, _911.y, _911.z, r4.w);
	float3 _916 = spvFMul(r4.xyz, float3(0.00346020772121846675872802734375));
	r9 = float4(_916.x, _916.y, _916.z, r9.w);
	float3 _921 = floor(r9.xyz);
	r9 = float4(_921.x, _921.y, _921.z, r9.w);
	float3 _926 = spvFMul(r9.xyz, float3(289.0));
	r9 = float4(_926.x, _926.y, _926.z, r9.w);
	float3 _934 = spvFAdd(r4.xyz, -r9.xyz);
	r4 = float4(_934.x, _934.y, _934.z, r4.w);
	float3 _939 = spvFMul(r4.xyz, float3(0.024390242993831634521484375));
	r4 = float4(_939.x, _939.y, _939.z, r4.w);
	float3 _944 = fract(r4.xyz);
	r4 = float4(_944.x, _944.y, _944.z, r4.w);
	float3 _949 = spvFMul(r4.xyz, float3(2.0));
	r4 = float4(_949.x, _949.y, _949.z, r4.w);
	float3 _954 = spvFAdd(r4.xyz, float3(-1.0));
	r4 = float4(_954.x, _954.y, _954.z, r4.w);
	float3 _959 = spvFAdd(r4.xyz, float3(0.5));
	r9 = float4(_959.x, _959.y, _959.z, r9.w);
	float3 _964 = floor(r9.xyz);
	r9 = float4(_964.x, _964.y, _964.z, r9.w);
	float3 _972 = spvFAdd(r4.xyz, -r9.xyz);
	r9 = float4(_972.x, _972.y, _972.z, r9.w);
	float3 _978 = spvFAdd(abs(r4.xyz), float3(-0.5));
	r4 = float4(_978.x, _978.y, _978.z, r4.w);
	float3 _985 = spvFMul(r9.xyz, r9.xyz);
	float4 r11;
	r11 = float4(_985.x, _985.y, _985.z, r11.w);
	float3 _992 = spvFMul(r4.xyz, r4.xyz);
	float4 r12;
	r12 = float4(_992.x, _992.y, _992.z, r12.w);
	float3 _999 = spvFAdd(r11.xyz, r12.xyz);
	r11 = float4(_999.x, _999.y, _999.z, r11.w);
	float3 _1004 = spvFMul(r11.xyz, float3(0.8537347316741943359375));
	r11 = float4(_1004.x, _1004.y, _1004.z, r11.w);
	float3 _1010 = spvFAdd(-r11.xyz, float3(1.792842864990234375));
	r11 = float4(_1010.x, _1010.y, _1010.z, r11.w);
	r12.x = dot(r8.zw, r8.zw);
	float4 r13 = spvFAdd(r8.zwzw, float4(0.211324870586395263671875, 0.211324870586395263671875, -0.57735025882720947265625, -0.57735025882720947265625));
	float2 _1026 = spvFAdd(r10.zw, r13.xy);
	r13 = float4(_1026.x, _1026.y, r13.z, r13.w);
	r12.y = dot(r13.xy, r13.xy);
	r12.z = dot(r13.zw, r13.zw);
	float3 _1044 = spvFAdd(-r12.xyz, float3(0.5));
	r10 = float4(_1044.x, _1044.y, _1044.z, r10.w);
	float3 _1049 = precise::max(r10.xyz, float3(0.0));
	r10 = float4(_1049.x, _1049.y, _1049.z, r10.w);
	float3 _1056 = spvFMul(r10.xyz, r10.xyz);
	r10 = float4(_1056.x, _1056.y, _1056.z, r10.w);
	float3 _1063 = spvFMul(r10.xyz, r10.xyz);
	r10 = float4(_1063.x, _1063.y, _1063.z, r10.w);
	float3 _1070 = spvFMul(r11.xyz, r10.xyz);
	r10 = float4(_1070.x, _1070.y, _1070.z, r10.w);
	r0.y = spvFMul(r8.z, r9.x);
	float2 _1083 = spvFMul(r9.yz, r13.xz);
	r9 = float4(_1083.x, _1083.y, r9.z, r9.w);
	float2 _1090 = spvFMul(r4.yz, r13.yw);
	r4 = float4(r4.x, _1090.x, _1090.y, r4.w);
	r2.w = spvFMul(r8.w, r4.x);
	r11.x = spvFAdd(r0.y, r2.w);
	float2 _1109 = spvFAdd(r4.yz, r9.xy);
	r11 = float4(r11.x, _1109.x, _1109.y, r11.w);
	r0.y = dot(r10.xyz, r11.xyz);
	r0.y = spvFMul(r0.y, 130.0);
	r0.y = spvFAdd(r0.y, in.v4.y);
	float3 _1134 = spvFAdd(r0.yyy, float3(0.300000011920928955078125, 0.60000002384185791015625, 0.89999997615814208984375));
	r4 = float4(_1134.x, _1134.y, _1134.z, r4.w);
	r0.y = spvFMul(cb10_10._m0[2u].w, cb10_10._m0[57u].z);
	float3 _1149 = spvFAdd(r4.xyz, r0.yyy);
	r4 = float4(_1149.x, _1149.y, _1149.z, r4.w);
	float3 _1154 = fract(r4.xyz);
	r4 = float4(_1154.x, _1154.y, _1154.z, r4.w);
	float3 _1159 = spvFMul(r4.xyz, float3(2.0));
	r4 = float4(_1159.x, _1159.y, _1159.z, r4.w);
	float3 _1164 = spvFAdd(r4.xyz, float3(-1.0));
	r4 = float4(_1164.x, _1164.y, _1164.z, r4.w);
	float3 _1170 = spvFMul(abs(r4.xyz), float3(2.0));
	r4 = float4(_1170.x, _1170.y, _1170.z, r4.w);
	float3 _1175 = spvFAdd(r4.xyz, float3(-1.0));
	r4 = float4(_1175.x, _1175.y, _1175.z, r4.w);
	float3 _1180 = spvFAdd(r4.xyz, float3(1.0));
	r4 = float4(_1180.x, _1180.y, _1180.z, r4.w);
	float3 _1185 = spvFMul(r4.xyz, float3(0.5));
	r4 = float4(_1185.x, _1185.y, _1185.z, r4.w);
	float3 _1190 = precise::max(r4.xyz, float3(0.0));
	r4 = float4(_1190.x, _1190.y, _1190.z, r4.w);
	float3 _1197 = spvFMul(r4.xyz, float3(-2.0));
	r9 = float4(_1197.x, _1197.y, _1197.z, r9.w);
	float3 _1204 = spvFMul(r4.xyz, r4.xyz);
	r4 = float4(_1204.x, _1204.y, _1204.z, r4.w);
	float3 _1210 = spvFAdd(r9.xyz, float3(3.0));
	r9 = float4(_1210.x, _1210.y, _1210.z, r9.w);
	float3 _1217 = spvFMul(r4.xyz, r9.xyz);
	r4 = float4(_1217.x, _1217.y, _1217.z, r4.w);
	float3 _1224 = spvFMul(r0.zzz, r4.xyz);
	r4 = float4(_1224.x, _1224.y, _1224.z, r4.w);
	float3 _1231 = spvFMul(r4.xyz, in.v4.xxx);
	r4 = float4(_1231.x, _1231.y, _1231.z, r4.w);
	float3 _1238 = spvFAdd(r3.xyz, r4.xyz);
	r3 = float4(_1238.x, _1238.y, _1238.z, r3.w);
	r0.y = spvFAdd(-r0.x, 1.0);
	r1.z = spvFAdd(r0.x, r0.y);
	r0.y = dot(float2(1.0, 0.0), r1.zw);
	r0.x = 0.0;
	float2 _1261 = spvFMul(r0.ww, r0.xy);
	r1 = float4(_1261.x, _1261.y, r1.z, r1.w);
	r0 = float4(in.v2.x, in.v2.y, in.v2.z, r0.w);
	r0.w = 0.0;
	r4.y = dot(r1.xyxw, r0);
	r4.z = dot(r7, r0);
	r4.x = dot(r6, r0);
	r0.x = dot(r4.xyz, r2.xyz);
	r0.y = dot(r1.xyxw, r5);
	r0.y /= 30.0;
	r0.z = dot(r8.xy, r8.xy);
	r0.z = rsqrt(r0.z);
	float2 _1311 = spvFMul(r0.zz, r8.xy);
	r0 = float4(r0.x, r0.y, _1311.x, _1311.y);
	r0.z = dot(r0.zw, r2.xz);
	r0.z = spvFMul(r0.z, 0.5);
	r0.z = spvFAdd(r0.z, 0.5);
	r0.y = spvFMul(r0.z, r0.y);
	r0.x = spvFMul(abs(r0.x), r0.y);
	r0.x = spvFMul(r0.x, 0.800000011920928955078125);
	r0.x = precise::clamp(spvFAdd(r0.x, 0.20000000298023223876953125), 0.0, 1.0);
	float3 _1356 = spvFMul(r0.xxx, r3.xyz);
	r0 = float4(_1356.x, _1356.y, _1356.z, r0.w);
	float3 _1363 = spvFAdd(r0.xyz, r5.xyz);
	r0 = float4(_1363.x, _1363.y, _1363.z, r0.w);
	r0.w = 1.0;
	r1.x = dot(r1.xyxw, r0);
	float3 _1378 = r1.xxx * cb3_3._m0[6u].xyz;
	r1 = float4(r1.x, _1378.x, _1378.y, _1378.z);
	r2 = r1.xxxx * cb3_3._m0[30u];
	r1.x = dot(r6, r0);
	r0.x = dot(r7, r0);
	float3 _1403 = fma(cb3_3._m0[5u].xyz, r1.xxx, r1.yzw);
	r0 = float4(r0.x, _1403.x, _1403.y, _1403.z);
	r1 = fma(cb3_3._m0[29u], r1.xxxx, r2);
	r1 = fma(cb3_3._m0[31u], r0.xxxx, r1);
	float3 _1428 = fma(cb3_3._m0[7u].xyz, r0.xxx, r0.yzw);
	r0 = float4(_1428.x, _1428.y, _1428.z, r0.w);
	float3 _1436 = r0.xyz + cb3_3._m0[8u].xyz;
	r0 = float4(_1436.x, _1436.y, _1436.z, r0.w);
	out.o1 = r1 + cb3_3._m0[32u];
	r1 = r0.yyyy * cb3_3._m0[14u];
	r1 = fma(cb3_3._m0[13u], r0.xxxx, r1);
	r1 = fma(cb3_3._m0[15u], r0.zzzz, r1);
	out.o3 = r0.xyz;
	out.gl_Position = r1 + cb3_3._m0[16u];
	out.o2 = in.v5;
	out.gl_Position.y = -(out.gl_Position.y);    // Invert Y-axis for Metal
	return out;
}

