#pragma clang diagnostic ignored "-Wmissing-prototypes"

#include <metal_stdlib>
#include <simd/simd.h>

using namespace metal;

template<typename T>
T spvFMul(T l, T r)
{
	return fma(l, r, T(0));
}

template<typename T, int Cols, int Rows>
vec<T, Cols> spvFMulVectorMatrix(vec<T, Rows> v, matrix<T, Cols, Rows> m)
{
	vec<T, Cols> res = vec<T, Cols>(0);
	for (uint i = Rows; i > 0; --i)
	{
		vec<T, Cols> tmp(0);
		for (uint j = 0; j < Cols; ++j)
		{
			tmp[j] = m[j][i - 1];
		}
		res = fma(tmp, vec<T, Cols>(v[i - 1]), res);
	}
	return res;
}

template<typename T, int Cols, int Rows>
vec<T, Rows> spvFMulMatrixVector(matrix<T, Cols, Rows> m, vec<T, Cols> v)
{
	vec<T, Rows> res = vec<T, Rows>(0);
	for (uint i = Cols; i > 0; --i)
	{
		res = fma(m[i - 1], vec<T, Rows>(v[i - 1]), res);
	}
	return res;
}

template<typename T, int LCols, int LRows, int RCols, int RRows>
matrix<T, RCols, LRows> spvFMulMatrixMatrix(matrix<T, LCols, LRows> l, matrix<T, RCols, RRows> r)
{
	matrix<T, RCols, LRows> res;
	for (uint i = 0; i < RCols; i++)
	{
		vec<T, RCols> tmp(0);
		for (uint j = 0; j < LCols; j++)
		{
			tmp = fma(vec<T, RCols>(r[i][j]), l[j], tmp);
		}
		res[i] = tmp;
	}
	return res;
}

template<typename T>
T spvFAdd(T l, T r)
{
	return fma(T(1), l, r);
}

struct cb58_struct
{
	float4 _m0[58];
};

struct cb33_struct
{
	float4 _m0[33];
};

struct cb1_struct
{
	float4 _m0[1];
};

struct vs1_out
{
	float4 o1 [[user(locn1)]];
	float3 o2 [[user(locn2)]];
	float4 o3 [[user(locn3)]];
	float2 o4 [[user(locn4)]];
	float4 o5 [[user(locn5)]];
	float4 gl_Position [[position]];
};

struct vs1_in
{
	float4 v1 [[attribute(1)]];
	float3 v2 [[attribute(2)]];
	float4 v3 [[attribute(3)]];
	float4 v4 [[attribute(4)]];
	float2 v5 [[attribute(5)]];
};

vertex vs1_out vs1(vs1_in in [[stage_in]], constant cb1_struct& cb0_0 [[buffer(0)]], constant cb58_struct& cb10_10 [[buffer(1)]], constant cb33_struct& cb3_3 [[buffer(4)]], texture_buffer<uint> t4 [[texture(60)]], uint gl_InstanceIndex [[instance_id]], uint gl_BaseInstance [[base_instance]])
{
	vs1_out out = {};
	float4 v0;
	v0.x = as_type<float>(int(gl_InstanceIndex) - int(gl_BaseInstance));
	float4 r0;
	r0 = float4(float2(0.0, 1.0).x, r0.y, float2(0.0, 1.0).y, r0.w);
	r0.w = as_type<float>((as_type<int>(cb0_0._m0[0u].x) * 5184) + as_type<int>(v0.x));
	uint _103 = (uint(as_type<int>(r0.w)) * 8u) + (uint(0) >> 2u);
	float4 r1 = as_type<float4>(uint4(t4.read(uint(_103)).x, t4.read(uint((_103 + 2u))).x, t4.read(uint((_103 + 3u))).x, t4.read(uint((_103 + 1u))).x));
	r0.w = as_type<float>(t4.read(uint(((uint(as_type<int>(r0.w)) * 8u) + (uint(16) >> 2u)))).x);
	float4 r2;
	r2.x = dot(r1.xy, float2(0.3660254180431365966796875));
	float2 _140 = spvFAdd(r1.xy, r2.xx);
	r2 = float4(_140.x, _140.y, r2.z, r2.w);
	float2 _146 = floor(r2.xy);
	r2 = float4(_146.x, _146.y, r2.z, r2.w);
	float2 _153 = spvFMul(r2.xy, float2(0.00346020772121846675872802734375));
	r2 = float4(r2.x, r2.y, _153.x, _153.y);
	float2 _158 = floor(r2.zw);
	r2 = float4(r2.x, r2.y, _158.x, _158.y);
	float2 _165 = spvFMul(r2.zw, float2(289.0));
	r2 = float4(r2.x, r2.y, _165.x, _165.y);
	float2 _173 = spvFAdd(-r2.zw, r2.xy);
	r2 = float4(r2.x, r2.y, _173.x, _173.y);
	float2 _181 = spvFAdd(r1.xy, -r2.xy);
	float4 r3;
	r3 = float4(_181.x, _181.y, r3.z, r3.w);
	r2.x = dot(r2.xy, float2(0.211324870586395263671875));
	float2 _194 = spvFAdd(r2.xx, r3.xy);
	r2 = float4(_194.x, _194.y, r2.z, r2.w);
	r3.x = as_type<float>((r2.y < r2.x) ? 4294967295u : 0u);
	r3 = select(float4(0.0, 1.0, -0.0, -1.0), float4(1.0, 0.0, -1.0, -0.0), as_type<uint4>(r3.xxxx) != uint4(0u));
	r0.y = r3.y;
	float3 _225 = spvFAdd(r0.xyz, r2.www);
	r0 = float4(_225.x, _225.y, _225.z, r0.w);
	float3 _232 = spvFMul(r0.xyz, float3(34.0));
	float4 r4;
	r4 = float4(_232.x, _232.y, _232.z, r4.w);
	float3 _238 = spvFAdd(r4.xyz, float3(1.0));
	r4 = float4(_238.x, _238.y, _238.z, r4.w);
	float3 _245 = spvFMul(r0.xyz, r4.xyz);
	r0 = float4(_245.x, _245.y, _245.z, r0.w);
	float3 _251 = spvFMul(r0.xyz, float3(0.00346020772121846675872802734375));
	r4 = float4(_251.x, _251.y, _251.z, r4.w);
	float3 _256 = floor(r4.xyz);
	r4 = float4(_256.x, _256.y, _256.z, r4.w);
	float3 _262 = spvFMul(r4.xyz, float3(289.0));
	r4 = float4(_262.x, _262.y, _262.z, r4.w);
	float3 _270 = spvFAdd(r0.xyz, -r4.xyz);
	r0 = float4(_270.x, _270.y, _270.z, r0.w);
	float3 _277 = spvFAdd(r2.zzz, r0.xyz);
	r0 = float4(_277.x, _277.y, _277.z, r0.w);
	r4 = float4(float2(0.0, 1.0).x, r4.y, float2(0.0, 1.0).y, r4.w);
	r4.y = r3.x;
	float3 _289 = spvFAdd(r0.xyz, r4.xyz);
	r0 = float4(_289.x, _289.y, _289.z, r0.w);
	float3 _294 = spvFMul(r0.xyz, float3(34.0));
	r4 = float4(_294.x, _294.y, _294.z, r4.w);
	float3 _299 = spvFAdd(r4.xyz, float3(1.0));
	r4 = float4(_299.x, _299.y, _299.z, r4.w);
	float3 _306 = spvFMul(r0.xyz, r4.xyz);
	r0 = float4(_306.x, _306.y, _306.z, r0.w);
	float3 _311 = spvFMul(r0.xyz, float3(0.00346020772121846675872802734375));
	r4 = float4(_311.x, _311.y, _311.z, r4.w);
	float3 _316 = floor(r4.xyz);
	r4 = float4(_316.x, _316.y, _316.z, r4.w);
	float3 _321 = spvFMul(r4.xyz, float3(289.0));
	r4 = float4(_321.x, _321.y, _321.z, r4.w);
	float3 _329 = spvFAdd(r0.xyz, -r4.xyz);
	r0 = float4(_329.x, _329.y, _329.z, r0.w);
	float3 _336 = spvFMul(r0.xyz, float3(0.024390242993831634521484375));
	r0 = float4(_336.x, _336.y, _336.z, r0.w);
	float3 _341 = fract(r0.xyz);
	r0 = float4(_341.x, _341.y, _341.z, r0.w);
	float3 _348 = spvFMul(r0.xyz, float3(2.0));
	r0 = float4(_348.x, _348.y, _348.z, r0.w);
	float3 _354 = spvFAdd(r0.xyz, float3(-1.0));
	r0 = float4(_354.x, _354.y, _354.z, r0.w);
	float3 _361 = spvFAdd(r0.xyz, float3(0.5));
	r4 = float4(_361.x, _361.y, _361.z, r4.w);
	float3 _366 = floor(r4.xyz);
	r4 = float4(_366.x, _366.y, _366.z, r4.w);
	float3 _374 = spvFAdd(r0.xyz, -r4.xyz);
	r4 = float4(_374.x, _374.y, _374.z, r4.w);
	float3 _382 = spvFAdd(abs(r0.xyz), float3(-0.5));
	r0 = float4(_382.x, _382.y, _382.z, r0.w);
	float3 _389 = spvFMul(r4.xyz, r4.xyz);
	float4 r5;
	r5 = float4(_389.x, _389.y, _389.z, r5.w);
	float3 _396 = spvFMul(r0.xyz, r0.xyz);
	float4 r6;
	r6 = float4(_396.x, _396.y, _396.z, r6.w);
	float3 _403 = spvFAdd(r5.xyz, r6.xyz);
	r5 = float4(_403.x, _403.y, _403.z, r5.w);
	float3 _410 = spvFMul(r5.xyz, float3(0.8537347316741943359375));
	r5 = float4(_410.x, _410.y, _410.z, r5.w);
	float3 _418 = spvFAdd(-r5.xyz, float3(1.792842864990234375));
	r5 = float4(_418.x, _418.y, _418.z, r5.w);
	r6 = spvFAdd(r2.xyxy, float4(0.211324870586395263671875, 0.211324870586395263671875, -0.57735025882720947265625, -0.57735025882720947265625));
	float2 _430 = spvFAdd(r3.zw, r6.xy);
	r6 = float4(_430.x, _430.y, r6.z, r6.w);
	r3.y = dot(r6.xy, r6.xy);
	r3.x = dot(r2.xy, r2.xy);
	r3.z = dot(r6.zw, r6.zw);
	float3 _454 = spvFAdd(-r3.xyz, float3(0.5));
	r3 = float4(_454.x, _454.y, _454.z, r3.w);
	float3 _460 = precise::max(r3.xyz, float3(0.0));
	r3 = float4(_460.x, _460.y, _460.z, r3.w);
	float3 _467 = spvFMul(r3.xyz, r3.xyz);
	r3 = float4(_467.x, _467.y, _467.z, r3.w);
	float3 _474 = spvFMul(r3.xyz, r3.xyz);
	r3 = float4(_474.x, _474.y, _474.z, r3.w);
	float3 _481 = spvFMul(r5.xyz, r3.xyz);
	r3 = float4(_481.x, _481.y, _481.z, r3.w);
	r2.x = spvFMul(r2.x, r4.x);
	float2 _494 = spvFMul(r4.yz, r6.xz);
	r2 = float4(r2.x, r2.y, _494.x, _494.y);
	float2 _501 = spvFMul(r0.yz, r6.yw);
	r0 = float4(r0.x, _501.x, _501.y, r0.w);
	r0.x = spvFMul(r2.y, r0.x);
	float3 _514 = spvFAdd(r0.xyz, r2.xzw);
	r4 = float4(_514.x, _514.y, _514.z, r4.w);
	r0.x = dot(r3.xyz, r4.xyz);
	r0.x = spvFMul(r0.x, 130.0);
	r0.x = spvFAdd(r0.x, in.v4.y);
	r0.x = spvFMul(r0.x, 6.283185482025146484375);
	r0.y = spvFMul(cb10_10._m0[57u].x, 0.25);
	r0.y = spvFMul(r0.y, cb10_10._m0[2u].w);
	r0.x = spvFAdd(r0.x, r0.y);
	r0.y = cos(r0.x);
	r2 = spvFMul(r0.xxxx, float4(3.0, 5.0, 7.0, 25.0));
	float3 _574 = cos(r2.xyz);
	r2 = float4(_574.x, _574.y, _574.z, r2.w);
	r0.x = sin(r2.w);
	r0.x = spvFMul(r0.x, 0.100000001490116119384765625);
	r0.y = spvFMul(r0.y, r2.x);
	r0.y = spvFMul(r2.y, r0.y);
	r0.y = spvFMul(r2.z, r0.y);
	r0.x = spvFAdd(r0.x, r0.y);
	float2 _617 = spvFMul(cb10_10._m0[55u].ww, float2(4.19999980926513671875, 0.3499999940395355224609375));
	r0 = float4(r0.x, _617.x, _617.y, r0.w);
	float2 _625 = spvFMul(r0.yz, cb10_10._m0[57u].yw);
	r0 = float4(r0.x, _625.x, _625.y, r0.w);
	r0.x = spvFMul(r0.y, r0.x);
	r0.y = dot(cb10_10._m0[55u].xyz, cb10_10._m0[55u].xyz);
	r0.y = rsqrt(r0.y);
	float3 _651 = spvFMul(r0.yyy, cb10_10._m0[55u].xyz);
	r2 = float4(_651.x, _651.y, _651.z, r2.w);
	float3 _658 = spvFMul(r0.xxx, r2.xyz);
	r3 = float4(_658.x, _658.y, _658.z, r3.w);
	r0.x = spvFAdd(-in.v4.z, 1.0);
	float3 _670 = spvFMul(r0.xxx, r3.xyz);
	r3 = float4(_670.x, _670.y, _670.z, r3.w);
	r4 = float4(float2(0.0, 1.0).x, r4.y, float2(0.0, 1.0).y, r4.w);
	r5 = float4(float2(0.0, 1.0).x, r5.y, float2(0.0, 1.0).y, r5.w);
	r0.x = spvFMul(in.v1.w, 13.0);
	r0.x = exp2(r0.x);
	float3 _690 = spvFMul(r0.xxx, in.v1.xyz);
	r6 = float4(_690.x, _690.y, _690.z, r6.w);
	float4 r7;
	r7.y = 0.0;
	float4 r8;
	r8 = float4(r8.x, r8.y, r1.y, r1.x);
	r8.x = sin(r1.z);
	r0.x = cos(r1.z);
	r7.x = dot(float2(1.0, 0.0), r8.xz);
	r8.y = r0.x;
	r7.z = dot(float2(1.0, 0.0), r8.yz);
	float4 r9;
	r9.w = r8.z;
	float3 _722 = spvFMul(r0.www, r7.xyz);
	r9 = float4(_722.x, _722.y, _722.z, r9.w);
	r6.w = 1.0;
	r7.y = dot(r9, r6);
	float4 r10;
	r10.y = 0.0;
	r8.x = -r8.x;
	r10.z = dot(float2(1.0, 0.0), r8.xw);
	r10.x = dot(float2(1.0, 0.0), r8.yw);
	float3 _747 = spvFMul(r0.www, r10.xyz);
	r8 = float4(_747.x, _747.y, _747.z, r8.w);
	r7.x = dot(r8, r6);
	r0.y = dot(r7.xy, float2(0.3660254180431365966796875));
	float2 _762 = spvFAdd(r0.yy, r7.xy);
	r7 = float4(r7.x, r7.y, _762.x, _762.y);
	float2 _767 = floor(r7.zw);
	r7 = float4(r7.x, r7.y, _767.x, _767.y);
	float2 _772 = spvFMul(r7.zw, float2(0.00346020772121846675872802734375));
	r10 = float4(_772.x, _772.y, r10.z, r10.w);
	float2 _777 = floor(r10.xy);
	r10 = float4(_777.x, _777.y, r10.z, r10.w);
	float2 _782 = spvFMul(r10.xy, float2(289.0));
	r10 = float4(_782.x, _782.y, r10.z, r10.w);
	float2 _790 = spvFAdd(r7.zw, -r10.xy);
	r10 = float4(_790.x, _790.y, r10.z, r10.w);
	float2 _798 = spvFAdd(-r7.zw, r7.xy);
	r10 = float4(r10.x, r10.y, _798.x, _798.y);
	float2 _806 = spvFAdd(r1.xy, -r7.xy);
	r7 = float4(_806.x, _806.y, r7.z, r7.w);
	r0.y = dot(r7.zw, float2(0.211324870586395263671875));
	float2 _817 = spvFAdd(r0.yy, r10.zw);
	r7 = float4(r7.x, r7.y, _817.x, _817.y);
	r0.y = as_type<float>((r7.w < r7.z) ? 4294967295u : 0u);
	float4 r11 = select(float4(0.0, 1.0, -0.0, -1.0), float4(1.0, 0.0, -1.0, -0.0), as_type<uint4>(r0.yyyy) != uint4(0u));
	r5.y = r11.y;
	float3 _840 = spvFAdd(r5.xyz, r10.yyy);
	r5 = float4(_840.x, _840.y, _840.z, r5.w);
	float3 _845 = spvFMul(r5.xyz, float3(34.0));
	r10 = float4(r10.x, _845.x, _845.y, _845.z);
	float3 _850 = spvFAdd(r10.yzw, float3(1.0));
	r10 = float4(r10.x, _850.x, _850.y, _850.z);
	float3 _857 = spvFMul(r5.xyz, r10.yzw);
	r5 = float4(_857.x, _857.y, _857.z, r5.w);
	float3 _862 = spvFMul(r5.xyz, float3(0.00346020772121846675872802734375));
	r10 = float4(r10.x, _862.x, _862.y, _862.z);
	float3 _867 = floor(r10.yzw);
	r10 = float4(r10.x, _867.x, _867.y, _867.z);
	float3 _872 = spvFMul(r10.yzw, float3(289.0));
	r10 = float4(r10.x, _872.x, _872.y, _872.z);
	float3 _880 = spvFAdd(r5.xyz, -r10.yzw);
	r5 = float4(_880.x, _880.y, _880.z, r5.w);
	float3 _887 = spvFAdd(r10.xxx, r5.xyz);
	r5 = float4(_887.x, _887.y, _887.z, r5.w);
	r4.y = r11.x;
	float3 _897 = spvFAdd(r4.xyz, r5.xyz);
	r4 = float4(_897.x, _897.y, _897.z, r4.w);
	float3 _902 = spvFMul(r4.xyz, float3(34.0));
	r5 = float4(_902.x, _902.y, _902.z, r5.w);
	float3 _907 = spvFAdd(r5.xyz, float3(1.0));
	r5 = float4(_907.x, _907.y, _907.z, r5.w);
	float3 _914 = spvFMul(r4.xyz, r5.xyz);
	r4 = float4(_914.x, _914.y, _914.z, r4.w);
	float3 _919 = spvFMul(r4.xyz, float3(0.00346020772121846675872802734375));
	r5 = float4(_919.x, _919.y, _919.z, r5.w);
	float3 _924 = floor(r5.xyz);
	r5 = float4(_924.x, _924.y, _924.z, r5.w);
	float3 _929 = spvFMul(r5.xyz, float3(289.0));
	r5 = float4(_929.x, _929.y, _929.z, r5.w);
	float3 _937 = spvFAdd(r4.xyz, -r5.xyz);
	r4 = float4(_937.x, _937.y, _937.z, r4.w);
	float3 _942 = spvFMul(r4.xyz, float3(0.024390242993831634521484375));
	r4 = float4(_942.x, _942.y, _942.z, r4.w);
	float3 _947 = fract(r4.xyz);
	r4 = float4(_947.x, _947.y, _947.z, r4.w);
	float3 _952 = spvFMul(r4.xyz, float3(2.0));
	r4 = float4(_952.x, _952.y, _952.z, r4.w);
	float3 _957 = spvFAdd(r4.xyz, float3(-1.0));
	r4 = float4(_957.x, _957.y, _957.z, r4.w);
	float3 _962 = spvFAdd(r4.xyz, float3(0.5));
	r5 = float4(_962.x, _962.y, _962.z, r5.w);
	float3 _967 = floor(r5.xyz);
	r5 = float4(_967.x, _967.y, _967.z, r5.w);
	float3 _975 = spvFAdd(r4.xyz, -r5.xyz);
	r5 = float4(_975.x, _975.y, _975.z, r5.w);
	float3 _981 = spvFAdd(abs(r4.xyz), float3(-0.5));
	r4 = float4(_981.x, _981.y, _981.z, r4.w);
	float3 _988 = spvFMul(r5.xyz, r5.xyz);
	r10 = float4(_988.x, _988.y, _988.z, r10.w);
	float3 _995 = spvFMul(r4.xyz, r4.xyz);
	float4 r12;
	r12 = float4(_995.x, _995.y, _995.z, r12.w);
	float3 _1002 = spvFAdd(r10.xyz, r12.xyz);
	r10 = float4(_1002.x, _1002.y, _1002.z, r10.w);
	float3 _1007 = spvFMul(r10.xyz, float3(0.8537347316741943359375));
	r10 = float4(_1007.x, _1007.y, _1007.z, r10.w);
	float3 _1013 = spvFAdd(-r10.xyz, float3(1.792842864990234375));
	r10 = float4(_1013.x, _1013.y, _1013.z, r10.w);
	r12.x = dot(r7.zw, r7.zw);
	float4 r13 = spvFAdd(r7.zwzw, float4(0.211324870586395263671875, 0.211324870586395263671875, -0.57735025882720947265625, -0.57735025882720947265625));
	float2 _1029 = spvFAdd(r11.zw, r13.xy);
	r13 = float4(_1029.x, _1029.y, r13.z, r13.w);
	r12.y = dot(r13.xy, r13.xy);
	r12.z = dot(r13.zw, r13.zw);
	float3 _1047 = spvFAdd(-r12.xyz, float3(0.5));
	r11 = float4(_1047.x, _1047.y, _1047.z, r11.w);
	float3 _1052 = precise::max(r11.xyz, float3(0.0));
	r11 = float4(_1052.x, _1052.y, _1052.z, r11.w);
	float3 _1059 = spvFMul(r11.xyz, r11.xyz);
	r11 = float4(_1059.x, _1059.y, _1059.z, r11.w);
	float3 _1066 = spvFMul(r11.xyz, r11.xyz);
	r11 = float4(_1066.x, _1066.y, _1066.z, r11.w);
	float3 _1073 = spvFMul(r10.xyz, r11.xyz);
	r10 = float4(_1073.x, _1073.y, _1073.z, r10.w);
	r0.y = spvFMul(r7.z, r5.x);
	float2 _1086 = spvFMul(r5.yz, r13.xz);
	r5 = float4(_1086.x, _1086.y, r5.z, r5.w);
	float2 _1093 = spvFMul(r4.yz, r13.yw);
	r4 = float4(r4.x, _1093.x, _1093.y, r4.w);
	r2.w = spvFMul(r7.w, r4.x);
	r11.x = spvFAdd(r0.y, r2.w);
	float2 _1112 = spvFAdd(r4.yz, r5.xy);
	r11 = float4(r11.x, _1112.x, _1112.y, r11.w);
	r0.y = dot(r10.xyz, r11.xyz);
	r0.y = spvFMul(r0.y, 130.0);
	r0.y = spvFAdd(r0.y, in.v4.y);
	float3 _1137 = spvFAdd(r0.yyy, float3(0.300000011920928955078125, 0.60000002384185791015625, 0.89999997615814208984375));
	r4 = float4(_1137.x, _1137.y, _1137.z, r4.w);
	r0.y = spvFMul(cb10_10._m0[2u].w, cb10_10._m0[57u].z);
	float3 _1152 = spvFAdd(r4.xyz, r0.yyy);
	r4 = float4(_1152.x, _1152.y, _1152.z, r4.w);
	float3 _1157 = fract(r4.xyz);
	r4 = float4(_1157.x, _1157.y, _1157.z, r4.w);
	float3 _1162 = spvFMul(r4.xyz, float3(2.0));
	r4 = float4(_1162.x, _1162.y, _1162.z, r4.w);
	float3 _1167 = spvFAdd(r4.xyz, float3(-1.0));
	r4 = float4(_1167.x, _1167.y, _1167.z, r4.w);
	float3 _1173 = spvFMul(abs(r4.xyz), float3(2.0));
	r4 = float4(_1173.x, _1173.y, _1173.z, r4.w);
	float3 _1178 = spvFAdd(r4.xyz, float3(-1.0));
	r4 = float4(_1178.x, _1178.y, _1178.z, r4.w);
	float3 _1183 = spvFAdd(r4.xyz, float3(1.0));
	r4 = float4(_1183.x, _1183.y, _1183.z, r4.w);
	float3 _1188 = spvFMul(r4.xyz, float3(0.5));
	r4 = float4(_1188.x, _1188.y, _1188.z, r4.w);
	float3 _1193 = precise::max(r4.xyz, float3(0.0));
	r4 = float4(_1193.x, _1193.y, _1193.z, r4.w);
	float3 _1200 = spvFMul(r4.xyz, float3(-2.0));
	r5 = float4(_1200.x, _1200.y, _1200.z, r5.w);
	float3 _1207 = spvFMul(r4.xyz, r4.xyz);
	r4 = float4(_1207.x, _1207.y, _1207.z, r4.w);
	float3 _1213 = spvFAdd(r5.xyz, float3(3.0));
	r5 = float4(_1213.x, _1213.y, _1213.z, r5.w);
	float3 _1220 = spvFMul(r4.xyz, r5.xyz);
	r4 = float4(_1220.x, _1220.y, _1220.z, r4.w);
	float3 _1227 = spvFMul(r0.zzz, r4.xyz);
	r4 = float4(_1227.x, _1227.y, _1227.z, r4.w);
	float3 _1234 = spvFMul(r4.xyz, in.v4.xxx);
	r4 = float4(_1234.x, _1234.y, _1234.z, r4.w);
	float3 _1241 = spvFAdd(r3.xyz, r4.xyz);
	r3 = float4(_1241.x, _1241.y, _1241.z, r3.w);
	r0.y = spvFAdd(-r0.x, 1.0);
	r1.z = spvFAdd(r0.x, r0.y);
	r0.y = dot(float2(1.0, 0.0), r1.zw);
	r0.x = 0.0;
	float2 _1264 = spvFMul(r0.ww, r0.xy);
	r1 = float4(_1264.x, _1264.y, r1.z, r1.w);
	r0 = float4(in.v2.x, in.v2.y, in.v2.z, r0.w);
	r0.w = 0.0;
	r4.y = dot(r1.xyxw, r0);
	r4.z = dot(r9, r0);
	r4.x = dot(r8, r0);
	r0.x = dot(r4.xyz, r2.xyz);
	r0.y = dot(r1.xyxw, r6);
	r0.y /= 30.0;
	r0.z = dot(r7.xy, r7.xy);
	r0.z = rsqrt(r0.z);
	float2 _1314 = spvFMul(r0.zz, r7.xy);
	r0 = float4(r0.x, r0.y, _1314.x, _1314.y);
	r0.z = dot(r0.zw, r2.xz);
	r0.z = spvFMul(r0.z, 0.5);
	r0.z = spvFAdd(r0.z, 0.5);
	r0.y = spvFMul(r0.z, r0.y);
	r0.x = spvFMul(abs(r0.x), r0.y);
	r0.x = spvFMul(r0.x, 0.800000011920928955078125);
	r0.x = precise::clamp(spvFAdd(r0.x, 0.20000000298023223876953125), 0.0, 1.0);
	float3 _1359 = spvFMul(r0.xxx, r3.xyz);
	r0 = float4(_1359.x, _1359.y, _1359.z, r0.w);
	float3 _1366 = spvFAdd(r0.xyz, r6.xyz);
	r0 = float4(_1366.x, _1366.y, _1366.z, r0.w);
	r0.w = 1.0;
	r1.z = dot(r1.xyxw, r0);
	float3 _1381 = r1.zzz * cb3_3._m0[6u].xyz;
	r2 = float4(_1381.x, _1381.y, _1381.z, r2.w);
	r3 = r1.zzzz * cb3_3._m0[30u];
	r1.z = dot(r8, r0);
	r0.x = dot(r9, r0);
	float3 _1406 = fma(cb3_3._m0[5u].xyz, r1.zzz, r2.xyz);
	r0 = float4(r0.x, _1406.x, _1406.y, _1406.z);
	r2 = fma(cb3_3._m0[29u], r1.zzzz, r3);
	r2 = fma(cb3_3._m0[31u], r0.xxxx, r2);
	float3 _1431 = fma(cb3_3._m0[7u].xyz, r0.xxx, r0.yzw);
	r0 = float4(_1431.x, _1431.y, _1431.z, r0.w);
	float3 _1439 = r0.xyz + cb3_3._m0[8u].xyz;
	r0 = float4(_1439.x, _1439.y, _1439.z, r0.w);
	out.o1 = r2 + cb3_3._m0[32u];
	r2 = r0.yyyy * cb3_3._m0[14u];
	r2 = fma(cb3_3._m0[13u], r0.xxxx, r2);
	r2 = fma(cb3_3._m0[15u], r0.zzzz, r2);
	out.o5 = float4(r0.x, r0.y, r0.z, out.o5.w);
	out.gl_Position = r2 + cb3_3._m0[16u];
	float3 _1480 = r1.yyy * cb3_3._m0[6u].xyz;
	r0 = float4(_1480.x, _1480.y, _1480.z, r0.w);
	float3 _1488 = r1.xxx * cb3_3._m0[6u].xyz;
	r1 = float4(_1488.x, _1488.y, _1488.z, r1.w);
	float3 _1498 = fma(cb3_3._m0[5u].xyz, r8.yyy, r0.xyz);
	r0 = float4(_1498.x, _1498.y, _1498.z, r0.w);
	float3 _1508 = fma(cb3_3._m0[7u].xyz, r9.yyy, r0.xyz);
	r0 = float4(_1508.x, _1508.y, _1508.z, r0.w);
	float3 _1515 = r0.xyz * in.v2.yyy;
	r2 = float4(_1515.x, _1515.y, _1515.z, r2.w);
	float3 _1522 = r0.xyz * in.v3.yyy;
	r0 = float4(_1522.x, _1522.y, _1522.z, r0.w);
	float3 _1532 = fma(cb3_3._m0[5u].xyz, r8.xxx, r1.xyz);
	r3 = float4(_1532.x, _1532.y, _1532.z, r3.w);
	float3 _1542 = fma(cb3_3._m0[5u].xyz, r8.zzz, r1.xyz);
	r1 = float4(_1542.x, _1542.y, _1542.z, r1.w);
	float3 _1552 = fma(cb3_3._m0[7u].xyz, r9.zzz, r1.xyz);
	r1 = float4(_1552.x, _1552.y, _1552.z, r1.w);
	float3 _1562 = fma(cb3_3._m0[7u].xyz, r9.xxx, r3.xyz);
	r3 = float4(_1562.x, _1562.y, _1562.z, r3.w);
	float3 _1571 = fma(r3.xyz, in.v2.xxx, r2.xyz);
	r2 = float4(_1571.x, _1571.y, _1571.z, r2.w);
	float3 _1580 = fma(r3.xyz, in.v3.xxx, r0.xyz);
	r0 = float4(_1580.x, _1580.y, _1580.z, r0.w);
	float3 _1589 = fma(r1.xyz, in.v3.zzz, r0.xyz);
	out.o3 = float4(_1589.x, _1589.y, _1589.z, out.o3.w);
	out.o2 = fma(r1.xyz, in.v2.zzz, r2.xyz);
	out.o3.w = in.v3.w;
	out.o4 = in.v5;
	out.o5.w = 1.0;
	out.gl_Position.y = -(out.gl_Position.y);    // Invert Y-axis for Metal
	return out;
}

